@@ -49,6 +49,7 @@ def write_default_ansible_cfg(work_dir,
     modules_path = ('/root/.ansible/plugins/modules:'
                     '/usr/share/ansible/tripleo-plugins/modules:'
                     '/usr/share/ansible/plugins/modules:'
+                    '/usr/share/ansible-modules:'
                     '%s/library' % constants.DEFAULT_VALIDATIONS_BASEDIR)
     lookups_path = (
         '/root/.ansible/plugins/lookup:'
@@ -133,6 +134,8 @@ def write_default_ansible_cfg(work_dir,
                os.path.join(work_dir, 'ansible-ssh'))
     config.set('ssh_connection', 'retries', '8')
     config.set('ssh_connection', 'pipelining', 'True')
+    # Related to https://github.com/ansible/ansible/issues/22127
+    config.set('ssh_connection', 'scp_if_ssh', 'True')
 
     # Set connection info in config file so that subsequent/nested ansible
     # calls can re-use it
@@ -450,7 +453,8 @@ class AnsiblePlaybookAction(base.TripleOAction):
                 os.chmod(command_path, 0o750)
 
             if self.command_timeout:
-                command = ['timeout', str(self.command_timeout)] + command
+                command = ['timeout', '-s', 'KILL',
+                           str(self.command_timeout)] + command
 
             if self.queue_name:
                 zaqar = self.get_messaging_client(context)
