@@ -23,7 +23,6 @@ from tripleo_common.actions import base
 from tripleo_common import constants
 from tripleo_common import exception
 from tripleo_common.utils import parameters as parameter_utils
-from tripleo_common.utils import plan as plan_utils
 from tripleo_common.utils import stack_parameters as stack_param_utils
 from tripleo_common.utils import template as template_utils
 
@@ -98,77 +97,6 @@ class UpdateRoleParametersAction(base.TripleOAction):
             return actions.Result(six.text_type(err))
 
 
-class GeneratePasswordsAction(base.TripleOAction):
-    """Generates passwords needed for Overcloud deployment
-
-    This method generates passwords and ensures they are stored in the
-    plan environment. By default, this method respects previously
-    generated passwords and adds new passwords as necessary.
-
-    If rotate_passwords is set to True, then passwords will be replaced as
-    follows:
-    - if password names are specified in the rotate_pw_list, then only those
-      passwords will be replaced.
-    - otherwise, all passwords not in the DO_NOT_ROTATE list (as they require
-      special handling, like KEKs and Fernet keys) will be replaced.
-    """
-
-    def __init__(self, container=constants.DEFAULT_CONTAINER_NAME,
-                 rotate_passwords=False,
-                 rotate_pw_list=[]):
-        super(GeneratePasswordsAction, self).__init__()
-        self.container = container
-        self.rotate_passwords = rotate_passwords
-        self.rotate_pw_list = rotate_pw_list
-
-    def run(self, context):
-        heat = self.get_orchestration_client(context)
-        swift = self.get_object_client(context)
-        mistral = self.get_workflow_client(context)
-
-        try:
-            return plan_utils.generate_passwords(
-                swift, heat, mistral, container=self.container,
-                rotate_passwords=self.rotate_passwords,
-                rotate_pw_list=self.rotate_pw_list)
-        except Exception as err:
-            LOG.exception(six.text_type(err))
-            return actions.Result(six.text_type(err))
-
-
-class GenerateFencingParametersAction(base.TripleOAction):
-    """Generates fencing configuration for a deployment.
-
-    :param nodes_json: list of nodes & attributes in json format
-    :param delay: time to wait before taking fencing action
-    :param ipmi_level: IPMI user level to use
-    :param ipmi_cipher: IPMI cipher suite to use
-    :param ipmi_lanplus: whether to use IPMIv2.0
-    """
-
-    def __init__(self, nodes_json, delay,
-                 ipmi_level, ipmi_cipher, ipmi_lanplus):
-        super(GenerateFencingParametersAction, self).__init__()
-        self.nodes_json = nodes_json
-        self.delay = delay
-        self.ipmi_level = ipmi_level
-        self.ipmi_cipher = ipmi_cipher
-        self.ipmi_lanplus = ipmi_lanplus
-
-    def run(self, context):
-        """Returns the parameters for fencing controller nodes"""
-        try:
-            return stack_param_utils.generate_fencing_parameters(
-                self.get_baremetal_client(context),
-                self.get_compute_client(context),
-                self.nodes_json,
-                self.delay, self.ipmi_level,
-                self.ipmi_cipher, self.ipmi_lanplus)
-        except Exception as err:
-            LOG.exception(six.text_type(err))
-            return actions.Result(six.text_type(err))
-
-
 class GetFlattenedParametersAction(base.TripleOAction):
     """Get the heat stack tree and parameters in flattened structure.
 
