@@ -35,28 +35,6 @@ from tripleo_common.utils import swift as swiftutils
 LOG = logging.getLogger(__name__)
 
 
-class CreateContainerAction(base.TripleOAction):
-    """Creates an object container
-
-    This action creates an object container for a given name.  If a container
-    with the same name already exists an exception is raised.
-    """
-
-    def __init__(self, container):
-        super(CreateContainerAction, self).__init__()
-        self.container = container
-
-    def run(self, context):
-        oc = self.get_object_client(context)
-        try:
-            plan_utils.create_plan_container(oc, self.container)
-
-        except Exception as err:
-            err_msg = ("Container creation failed for plan:%s" % (err))
-            LOG.exception(err_msg)
-            return actions.Result(error=err_msg)
-
-
 class ListPlansAction(base.TripleOAction):
     """Lists deployment plans
 
@@ -146,18 +124,12 @@ class ListRolesAction(base.TripleOAction):
     def run(self, context):
         try:
             swift = self.get_object_client(context)
-            roles_data = yaml.safe_load(swiftutils.get_object_string(
-                swift, self.container, self.role_file_name))
+            return roles_utils.get_roles_from_plan(
+                swift, container=self.container,
+                role_file_name=self.role_file_name,
+                detail=self.detail)
         except Exception as err:
-            err_msg = ("Error retrieving roles data from deployment plan: %s"
-                       % err)
-            LOG.exception(err_msg)
-            return actions.Result(error=err_msg)
-
-        if self.detail:
-            return roles_data
-        else:
-            return [role['name'] for role in roles_data]
+            return actions.Result(error=six.text_type(err))
 
 
 class ExportPlanAction(base.TripleOAction):
