@@ -17,9 +17,8 @@
 
 from collections import OrderedDict
 import logging
-import os
+import os.path
 import sys
-import tempfile
 import yaml
 
 from heatclient.exc import HTTPNotFound
@@ -93,6 +92,7 @@ class TripleoInventory(object):
                  undercloud_key_file=None, serial=1):
         self.session = session
         self.hclient = hclient
+        self.hosts_format_dict = False
         self.host_network = host_network or HOST_NETWORK
         self.auth_url = auth_url
         self.cacert = cacert
@@ -141,16 +141,14 @@ class TripleoInventory(object):
         """
         return self.UNDERCLOUD_SERVICES
 
-    def _hosts(self, alist, dynamic=True):
+    def _hosts(self, alist):
         """Static yaml inventories reqire a different hosts format?!"""
-        if not dynamic:
+        if self.hosts_format_dict:
             return {x: {} for x in alist}
         else:
             return alist
 
     def _get_stack(self):
-        if self.plan_name is None:
-            return None
         try:
             stack = self.hclient.stacks.get(self.plan_name)
         except HTTPNotFound:
@@ -160,10 +158,10 @@ class TripleoInventory(object):
 
         return stack
 
-    def list(self, dynamic=True):
+    def list(self):
         ret = OrderedDict({
             'Undercloud': {
-                'hosts': self._hosts(['undercloud'], dynamic),
+                'hosts': self._hosts(['undercloud']),
                 'vars': {
                     'ansible_host': 'localhost',
                     'ansible_python_interpreter': sys.executable,
@@ -174,7 +172,7 @@ class TripleoInventory(object):
                     'cacert': self.cacert,
                     'os_auth_token':
                     self.session.get_token() if self.session else None,
-                    'plan': None,
+                    'plan': self.plan_name,
                     'project_name': self.project_name,
                     'username': self.username,
                 },
@@ -201,7 +199,13 @@ class TripleoInventory(object):
         ret['Undercloud']['vars']['undercloud_service_list'] = \
             self.get_undercloud_service_list()
 
-        if dynamic:
+        admin_password = self.get_overcloud_environment().get(
+            'parameter_defaults', {}).get('AdminPassword')
+        if admin_password:
+            ret['Undercloud']['vars']['overcloud_admin_password'] =\
+                admin_password
+
+        if not self.hosts_format_dict:
             # Prevent Ansible from repeatedly calling us to get empty host
             # details
             ret['_meta'] = {'hostvars': self.hostvars}
@@ -209,14 +213,6 @@ class TripleoInventory(object):
         self.stack = self._get_stack()
         if not self.stack:
             return ret
-
-        ret['Undercloud']['vars']['plan'] = self.plan_name
-        admin_password = self.get_overcloud_environment().get(
-            'parameter_defaults', {}).get('AdminPassword')
-        if admin_password:
-            ret['Undercloud']['vars']['overcloud_admin_password'] =\
-                admin_password
-
         self.stack_outputs = StackOutputs(self.stack)
 
         keystone_url = self.stack_outputs.get('KeystoneURL')
@@ -267,7 +263,7 @@ class TripleoInventory(object):
 
                 children.append(role)
 
-                if not dynamic:
+                if self.hosts_format_dict:
                     hosts_format = hosts
                 else:
                     hosts_format = [h for h in hosts.keys()]
@@ -308,20 +304,11 @@ class TripleoInventory(object):
                 self.get_overcloud_environment().get(
                     'parameter_defaults', {}).get('ContainerCli')
 
-            ret['allovercloud'] = {
-                'children': self._hosts(sorted(children), dynamic),
+            ret['overcloud'] = {
+                'children': self._hosts(sorted(children)),
                 'vars': overcloud_vars
             }
 
-            ret[self.plan_name] = {
-                'children': self._hosts(['allovercloud'], dynamic)
-            }
-            if self.plan_name != 'overcloud':
-                ret['overcloud'] = {
-                    'children': self._hosts(['allovercloud'], dynamic),
-                    'deprecated': 'Deprecated by allovercloud group in Ussuri'
-                }
-
         # Associate services with roles
         roles_by_service = self.get_roles_by_service(
             self.stack_outputs.get('EnabledServices', {}))
@@ -353,7 +340,7 @@ class TripleoInventory(object):
             if service_children:
                 svc_host = service.lower()
                 ret[svc_host] = {
-                    'children': self._hosts(service_children, dynamic),
+                    'children': self._hosts(service_children),
                     'vars': {
                         'ansible_ssh_user': self.ansible_ssh_user
                     }
@@ -381,18 +368,13 @@ class TripleoInventory(object):
 
         # For some reason the json/yaml format needed for static and
         # dynamic inventories is different for the hosts/children?!
-        inventory = self.list(dynamic=False)
+        self.hosts_format_dict = True
+        inventory = self.list()
 
         if extra_vars:
             for var, value in extra_vars.items():
                 if var in inventory:
                     inventory[var]['vars'].update(value)
 
-        # Atomic update as concurrent tripleoclient commands can call this
-        inventory_file_dir = os.path.dirname(inventory_file_path)
-        with tempfile.NamedTemporaryFile(
-                'w',
-                dir=inventory_file_dir,
-                delete=False) as inventory_file:
+        with open(inventory_file_path, 'w') as inventory_file:
             yaml.dump(inventory, inventory_file, TemplateDumper)
-        os.rename(inventory_file.name, inventory_file_path)
