@@ -16,7 +16,6 @@ import mock
 
 
 from heatclient import exc as heatexceptions
-from mistral_lib import actions
 from oslo_concurrency import processutils
 from swiftclient import exceptions as swiftexceptions
 
@@ -54,23 +53,6 @@ notresources:
 """
 
 
-ROLES_DATA_YAML_CONTENTS = """
-- name: MyController
-  CountDefault: 1
-  ServicesDefault:
-    - OS::TripleO::Services::CACerts
-
-- name: Compute
-  HostnameFormatDefault: '%stackname%-novacompute-%index%'
-  ServicesDefault:
-    - OS::TripleO::Services::NovaCompute
-    - OS::TripleO::Services::DummyService
-
-- name: CustomRole
-  ServicesDefault:
-    - OS::TripleO::Services::Kernel
-"""
-
 SAMPLE_ROLE = """
 ###############################################################################
 # Role: sample                                                                #
@@ -143,69 +125,6 @@ UPDATED_ROLE_OBJ = {
 }
 
 
-class CreateContainerActionTest(base.TestCase):
-
-    def setUp(self):
-        super(CreateContainerActionTest, self).setUp()
-        # A container that name enforces all validation rules
-        self.container_name = 'Test-container-7'
-        self.expected_list = ['', [{'name': 'test1'}, {'name': 'test2'}]]
-        self.ctx = mock.MagicMock()
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run(self, get_obj_client_mock):
-
-        # Setup
-        swift = mock.MagicMock()
-        swift.get_account.return_value = self.expected_list
-        get_obj_client_mock.return_value = swift
-
-        # Test
-        action = plan.CreateContainerAction(self.container_name)
-        action.run(self.ctx)
-
-        # Verify
-        swift.put_container.assert_called_once_with(
-            self.container_name,
-            headers={'x-container-meta-usage-tripleo': 'plan'}
-        )
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run_container_exists(self, get_obj_client_mock):
-
-        # Setup
-        swift = mock.MagicMock()
-        swift.get_account.return_value = [
-            '', [{'name': 'Test-container-7'}, {'name': 'test2'}]]
-        get_obj_client_mock.return_value = swift
-
-        # Test
-        action = plan.CreateContainerAction(self.container_name)
-        result = action.run(self.ctx)
-
-        error_str = ('Container creation failed for plan:'
-                     'A container with the name %s already'
-                     ' exists.') % self.container_name
-        self.assertEqual(result, actions.Result(
-            None, error_str))
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run_invalid_name(self, get_obj_client_mock):
-        # Setup
-        swift = mock.MagicMock()
-        get_obj_client_mock.return_value = swift
-
-        # Test
-        action = plan.CreateContainerAction("invalid_underscore")
-        result = action.run(self.ctx)
-
-        error_str = ('Container creation failed for plan:'
-                     'The plan name must only contain '
-                     'letters, numbers or dashes')
-        self.assertEqual(result, actions.Result(
-            None, error_str))
-
-
 class ListPlansActionTest(base.TestCase):
 
     def setUp(self):
@@ -310,67 +229,6 @@ class DeletePlanActionTest(base.TestCase):
         swift.delete_container.assert_called_with(self.container_name)
 
 
-class ListRolesActionTest(base.TestCase):
-
-    def setUp(self):
-        super(ListRolesActionTest, self).setUp()
-        self.container = 'overcloud'
-        self.ctx = mock.MagicMock()
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run(self, get_obj_client_mock):
-        # setup swift
-        swift = mock.MagicMock()
-        swift.get_object.return_value = ({}, ROLES_DATA_YAML_CONTENTS)
-        get_obj_client_mock.return_value = swift
-
-        # Test
-        action = plan.ListRolesAction()
-        result = action.run(self.ctx)
-
-        # verify
-        expected = ['MyController', 'Compute', 'CustomRole']
-        self.assertEqual(expected, result)
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_run_show_detail(self, get_obj_client_mock):
-        # setup swift
-        swift = mock.MagicMock()
-        swift.get_object.return_value = ({}, ROLES_DATA_YAML_CONTENTS)
-        get_obj_client_mock.return_value = swift
-
-        # Test
-        action = plan.ListRolesAction(detail=True)
-        result = action.run(self.ctx)
-
-        # verify
-        expected = [
-            {u'CountDefault': 1,
-             u'ServicesDefault': [u'OS::TripleO::Services::CACerts'],
-             u'name': u'MyController'},
-            {u'HostnameFormatDefault': u'%stackname%-novacompute-%index%',
-             u'ServicesDefault': [u'OS::TripleO::Services::NovaCompute',
-                                  u'OS::TripleO::Services::DummyService'],
-             u'name': u'Compute'},
-            {u'ServicesDefault': [u'OS::TripleO::Services::Kernel'],
-             u'name': u'CustomRole'}]
-
-        self.assertEqual(expected, result)
-
-    @mock.patch('tripleo_common.actions.base.TripleOAction.get_object_client')
-    def test_no_roles_data_file(self, get_obj_client_mock):
-
-        swift = mock.MagicMock()
-        swift.get_object.side_effect = swiftexceptions.ClientException("404")
-        get_obj_client_mock.return_value = swift
-
-        action = plan.ListRolesAction()
-        result = action.run(self.ctx)
-
-        error_str = ('Error retrieving roles data from deployment plan: 404')
-        self.assertEqual(result.error, error_str)
-
-
 class ExportPlanActionTest(base.TestCase):
 
     def setUp(self):
