@@ -29,10 +29,7 @@ FAKE_STACK = {
     'outputs': [
         {'output_key': 'RoleConfig',
          'output_value': {
-             'foo_config': 'foo',
-             'external_deploy_steps_tasks': [{'name': 'Fake external task',
-                                              'debug': 'name=hello',
-                                              'when': 'step|int == 1'}]}},
+             'foo_config': 'foo'}},
         {'output_key': 'HostnameNetworkConfigMap',
          'output_value': {}},
         {'output_key': 'RoleData',
@@ -56,7 +53,6 @@ FAKE_STACK = {
                  'upgrade_tasks': [{'name': 'Stop fake service',
                                     'service': 'name=fake state=stopped',
                                     'when': ['nova_api_enabled.rc == 0',
-                                             False,
                                              'httpd_enabled.rc != 0',
                                              'step|int == 1']},
                                    {'name': 'Stop nova-compute service',
