@@ -317,10 +317,19 @@ class TestConfig(base.TestCase):
                          'uuid': 2},
                      'overcloud-novacompute-2': {
                          'uuid': 3}}}},
+            {'output_key': 'RoleData',
+             'output_value': {
+                 'Controller': {
+                     'ansible_group_vars': {
+                         'chrony_host': 'localhost',
+                         'chrony_acl': 'none',
+                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
+                     'chrony_host': '192.168.2.1',
+                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
@@ -722,10 +731,19 @@ class TestConfig(base.TestCase):
                          'a7db3010-a51f-4ae0-a791-2364d629d20d',
                          '8b07cd31-3083-4b88-a433-955f72039e2c',
                          '169b46f8-1965-4d90-a7de-f36fb4a830fe']}}},
+            {'output_key': 'RoleData',
+             'output_value': {
+                 'Controller': {
+                     'ansible_group_vars': {
+                         'chrony_host': 'localhost',
+                         'chrony_acl': 'none',
+                     }}}},
             {'output_key': 'RoleGroupVars',
              'output_value': {
                  'Controller': {
                      'any_errors_fatal': True,
+                     'chrony_host': '192.168.2.1',
+                     'chrony_foo': 'bar',
                      'max_fail_percentage': 15},
                  'Compute': {
                      'any_errors_fatal': True,
