@@ -20,6 +20,7 @@ import sys
 import yaml
 import zlib
 
+import six
 from swiftclient import exceptions as swiftexceptions
 
 from tripleo_common import constants
@@ -626,13 +627,14 @@ class PlanTest(base.TestCase):
         }
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
 
-        mock_workflow = mock.MagicMock()
-        result = plan_utils.generate_passwords(swift, mock_orchestration,
-                                               mock_workflow)
+        result = plan_utils.generate_passwords(swift, mock_orchestration)
 
         for password_param_name in constants.PASSWORD_PARAMETER_NAMES:
             self.assertTrue(password_param_name in result,
@@ -684,11 +686,16 @@ class PlanTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
 
-        mock_workflow = mock.MagicMock()
-
-        result = plan_utils.generate_passwords(swift, mock_orchestration,
-                                               mock_workflow)
+        result = plan_utils.generate_passwords(swift, mock_orchestration)
 
         # ensure old passwords used and no new generation
         self.assertEqual(_EXISTING_PASSWORDS, result)
@@ -698,6 +705,56 @@ class PlanTest(base.TestCase):
             "tripleo.parameters.get"
         )
 
+    @mock.patch('tripleo_common.utils.plan.'
+                'cache_delete')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_ssh_keypair')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'create_fernet_keys_repo_structure_and_keys')
+    @mock.patch('tripleo_common.utils.passwords.'
+                'get_snmpd_readonly_user_password')
+    def test_placement_passwords_upgrade(self,
+                                         mock_get_snmpd_readonly_user_password,
+                                         mock_fernet_keys_setup,
+                                         mock_create_ssh_keypair,
+                                         mock_cache):
+
+        mock_get_snmpd_readonly_user_password.return_value = "TestPassword"
+        mock_create_ssh_keypair.return_value = {'public_key': 'Foo',
+                                                'private_key': 'Bar'}
+        mock_fernet_keys_setup.return_value = {'/tmp/foo': {'content': 'Foo'},
+                                               '/tmp/bar': {'content': 'Bar'}}
+
+        passwords = _EXISTING_PASSWORDS.copy()
+
+        swift = mock.MagicMock(url="http://test.com")
+        mock_env = yaml.safe_dump({
+            'name': constants.DEFAULT_CONTAINER_NAME,
+            'temp_environment': 'temp_environment',
+            'template': 'template',
+            'environments': [{u'path': u'environments/test.yaml'}],
+            'passwords': passwords
+        }, default_flow_style=False)
+        swift.get_object.return_value = ({}, mock_env)
+
+        mock_orchestration = mock.MagicMock()
+        mock_orchestration.stacks.environment.return_value = {
+            'parameter_defaults': {}
+        }
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {},
+            'value': None
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
+
+        result = plan_utils.generate_passwords(swift, mock_orchestration)
+
+        self.assertEqual(
+            passwords['NovaPassword'],
+            result['PlacementPassword']
+        )
+
     @mock.patch('tripleo_common.utils.plan.'
                 'cache_delete')
     @mock.patch('tripleo_common.utils.passwords.'
@@ -734,13 +791,14 @@ class PlanTest(base.TestCase):
 
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
 
-        mock_workflow = mock.MagicMock()
         result = plan_utils.generate_passwords(swift, mock_orchestration,
-                                               mock_workflow,
                                                rotate_passwords=True)
 
         # ensure passwords in the DO_NOT_ROTATE_LIST are not modified
@@ -792,8 +850,12 @@ class PlanTest(base.TestCase):
         mock_orchestration.stacks.environment.return_value = {
             'parameter_defaults': {}
         }
+
         mock_resource = mock.MagicMock()
         mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
             'value': 'existing_value'
         }
         mock_orchestration.resources.get.return_value = mock_resource
@@ -808,9 +870,7 @@ class PlanTest(base.TestCase):
             'MysqlRootPassword'
         ]
 
-        mock_workflow = mock.MagicMock()
         result = plan_utils.generate_passwords(swift, mock_orchestration,
-                                               mock_workflow,
                                                rotate_passwords=True,
                                                rotate_pw_list=rotate_list)
 
@@ -868,9 +928,16 @@ class PlanTest(base.TestCase):
             }
         }
 
-        mock_workflow = mock.MagicMock()
-        result = plan_utils.generate_passwords(swift, mock_orchestration,
-                                               mock_workflow)
+        mock_resource = mock.MagicMock()
+        mock_resource.attributes = {
+            'endpoint_map': {
+                'PlacementPublic': {}
+            },
+            'value': 'existing_value'
+        }
+        mock_orchestration.resources.get.return_value = mock_resource
+
+        result = plan_utils.generate_passwords(swift, mock_orchestration)
 
         existing_passwords["AdminPassword"] = "ExistingPasswordInHeat"
         # ensure old passwords used and no new generation
@@ -987,3 +1054,47 @@ class PlanTest(base.TestCase):
             {'environments/containers-default-parameters.yaml': True},
             container='overcloud'
         )
+
+    def test_create_plan_container(self):
+        # Setup
+        container_name = 'Test-container-7'
+        swift = mock.MagicMock()
+        swift.get_account.return_value = [
+            '', [{'name': 'test1'}, {'name': 'test2'}]]
+
+        # Test
+        plan_utils.create_plan_container(swift, container_name)
+
+        # Verify
+        swift.put_container.assert_called_once_with(
+            container_name,
+            headers={'x-container-meta-usage-tripleo': 'plan'}
+        )
+
+    def test_container_exists(self):
+        # Setup
+        container_name = 'Test-container-7'
+        swift = mock.MagicMock()
+        swift.get_account.return_value = [
+            '', [{'name': 'Test-container-7'}, {'name': 'test2'}]]
+
+        # Test
+        error_str = ('A container with the name %s already'
+                     ' exists.') % container_name
+        err = self.assertRaises(RuntimeError,
+                                plan_utils.create_plan_container,
+                                swift, container_name)
+        self.assertEquals(error_str, six.text_type(err))
+
+    def test_run_invalid_name(self):
+        # Setup
+        container_name = 'Invalid_underscore'
+        swift = mock.MagicMock()
+
+        # Test
+        error_str = ('The plan name must only contain '
+                     'letters, numbers or dashes')
+        err = self.assertRaises(RuntimeError,
+                                plan_utils.create_plan_container,
+                                swift, container_name)
+        self.assertEquals(error_str, six.text_type(err))
