@@ -372,7 +372,7 @@ def update_plan_environment_with_image_parameters(
     return env
 
 
-def generate_passwords(swift, heat, mistral,
+def generate_passwords(swift, heat, mistral=None,
                        container=constants.DEFAULT_CONTAINER_NAME,
                        rotate_passwords=False, rotate_pw_list=None):
     """Generates passwords needed for Overcloud deployment
@@ -416,8 +416,18 @@ def generate_passwords(swift, heat, mistral,
     except heat_exc.HTTPNotFound:
         stack_env = None
 
+    try:
+        # We can't rely on the existence of PlacementPassword to
+        # determine if placement extraction has occured as it was added
+        # in stein while the service extraction was delayed to train.
+        # Inspect the endpoint map instead.
+        endpoint_res = heat.resources.get(container, 'EndpointMap')
+        endpoints = endpoint_res.attributes.get('endpoint_map', {})
+        placement_extracted = 'PlacementPublic' in endpoints
+    except heat_exc.HTTPNotFound:
+        placement_extracted = False
+
     passwords = password_utils.generate_passwords(
-        mistralclient=mistral,
         stack_env=stack_env,
         rotate_passwords=rotate_passwords
     )
@@ -433,6 +443,15 @@ def generate_passwords(swift, heat, mistral,
             if i not in env['passwords']:
                 env['passwords'][i] = env['passwords']['RabbitPassword']
 
+    # NOTE(owalsh): placement previously used NovaPassword
+    # Default to the same password for PlacementPassword if it is an
+    # upgrade (i.e NovaPassword is set) so we do not need to update the
+    # password in keystone
+    if not placement_extracted and 'NovaPassword' in env['passwords']:
+        LOG.debug('Setting PlacementPassword to NovaPassword')
+        env['passwords']['PlacementPassword'] = \
+            env['passwords']['NovaPassword']
+
     # ensure all generated passwords are present in plan env,
     # but respect any values previously generated and stored
     for name, password in passwords.items():
